# About

`webuipy` is a Python API client for [AUTOMATIC1111/stable-diffusion-webui](https://github.com/AUTOMATIC1111/stable-diffusion-webui)

## Installation

You can install `webuipy` using `pip`:

```
pip install webuipy
```

`webuipy` is supported on Python 3.7 and above.

## Test

```bash
pip install pytest
python -m pytest
```

## Packaging and Upload

```
python setup.py sdist
twine upload dist/*
```

